@@ -20,8 +20,11 @@ def enver(file):
         return os.environ.get(str(key))
     def setenv(key, val):
         '''设置env中对应key的值'''
-        if not val: val = getenv(key)
-        set_key(file, str(key), str(val))
+        if not val:
+            os.environ.pop(key)
+            unset_key(file, str(key))
+        else:
+            set_key(file, str(key), str(val))
     def getfile():
         return file
-    return getenv, setenv, getfile
\ No newline at end of file
+    return getenv, setenv, getfile
